unit _entryid;

interface

(*
** --_entryid.h----------------------------------------------------------------
**
**  Header file describing internal structure of EntryIDs returned
**  by Exchange Address Book provider.
**
**
**  Copyright (c) Microsoft Corp. 1986-1999.  All Rights Reserved.
**
** ----------------------------------------------------------------------------
*)

uses Windows, MAPIDefs;

{$IFDEF CPU64}
  //64 bit - align at 8 bytes
  {$A8}
{$ELSE}
  //32 bit
  {$A+}
{$ENDIF }

const

(*
 *  The version of this ABPs entryids
 *)
EMS_VERSION          = $000000001;

(*
 * The version of the entryids supported by the CreateEntry method in this
 * ABP.
 *)
NEW_OBJ_EID_VERSION = $00000002;

(*
 *  Valid values for the entry id's Type field are Mapi Display Types, plus:
 *)
AB_DT_CONTAINER     = $000000100;
AB_DT_TEMPLATE      = $000000101;
AB_DT_OOUSER        = $000000102;
AB_DT_SEARCH        = $000000200;

(*
 *  The EMS ABPs MAPIUID
 *
 *  This MAPIUID must be unique (see the Service Provider Writer's Guide on
 *  Constructing Entry IDs)
 *)
MUIDEMSAB : array[0..15] of byte =($DC, $A7, $40, $C8, $C0, $42, $10, $1A, $B4, $B9, $08, $00, $2B, $2F, $E1, $82);

(*
 *  Directory entry id structure
 *
 *  This entryid is permanent.
 *)

type

DIR_ENTRYID = packed record
    abFlags : array[0..3] of byte;
    muid : TMAPIUID;
    ulVersion : ULONG;
    ulType : ULONG;
end;

LPDIR_ENTRYID = ^DIR_ENTRYID;

//#define CBDIR_ENTRYID sizeof(DIR_ENTRYID)

(*
 *  Mail user entry id structure
 *
 *  This entryid is ephemeral.
 *)
USR_ENTRYID = packed record
    abFlags : array[0..3] of byte;
    muid : TMAPIUID;
    ulVersion : ULONG;
    ulType : ULONG;
    dwEph : DWORD;
end;

LPUSR_ENTRYID = ^USR_ENTRYID;

(*
 *  This entryid is permanent.
 *)
USR_PERMID = packed record
    abFlags : array[0..3] of byte;
    muid : TMAPIUID;
    ulVersion : ULONG;
    ulType : ULONG;
    szAddr : array[0..0] of AnsiChar;
end;

LPUSR_PERMID = ^USR_PERMID;

const

EPHEMERAL   = not (MAPI_NOTRECIP or  MAPI_THISSESSION or MAPI_NOW or MAPI_NOTRESERVED);

implementation

end.
 